@@ -19,6 +19,7 @@
 #define FITSHISTOGRAM
 
 #include "ui_fitshistogramui.h"
+#include "fitscommon.h"
 
 #include <QUndoCommand>
 #include <QPixmap>
@@ -29,7 +30,7 @@
 
 #define CIRCLE_DIM	16
 
-const int INITIAL_MAXIMUM_WIDTH = 1024;
+const int INITIAL_MAXIMUM_WIDTH = 500;
 
 class FITSTab;
 class QPixmap;
@@ -57,23 +58,39 @@ public:
     void constructHistogram(int hist_width, int hist_height);
     void updateHistogram();
     int  findMax(int hist_width);
-    int type;
+    void applyFilter(FITSScale ftype);
+    double getBinWidth() { return binWidth; }
+    double getJMIndex() { return JMIndex; }
+    int getMeanStdDev() { return mean_p_std;}
+    QVarLengthArray<int, INITIAL_MAXIMUM_WIDTH> getCumulativeFreq() { return cumulativeFreq; }
+    QVarLengthArray<int, INITIAL_MAXIMUM_WIDTH> getHistogram() { return histArray; }
+
+    FITSScale type;
     int napply;
     double histFactor;
+    double binWidth;
     double fits_min, fits_max;
     FITSTab *tab;
 
 private:
 
-    double binSize;
     histogramUI *ui;
     int histogram_height, histogram_width;
     QVarLengthArray<int, INITIAL_MAXIMUM_WIDTH> histArray;
+    QVarLengthArray<int, INITIAL_MAXIMUM_WIDTH> cumulativeFreq;
+    double JMIndex;
+    int mean;
+    int mean_p_std;
 
 public slots:
     void applyScale();
     void updateBoxes(int lowerLimit, int upperLimit);
     void updateIntenFreq(int x);
+    void minSliderUpdated(int value);
+    void maxSliderUpdated(int value);
+
+    void updateLowerLimit();
+    void updateUpperLimit();
 
 
 };
@@ -81,7 +98,7 @@ public slots:
 class FITSHistogramCommand : public QUndoCommand
 {
 public:
-    FITSHistogramCommand(QWidget * parent, FITSHistogram *inHisto, int newType, int lmin, int lmax);
+    FITSHistogramCommand(QWidget * parent, FITSHistogram *inHisto, FITSScale newType, int lmin, int lmax);
     virtual ~FITSHistogramCommand();
 
     virtual void redo();
@@ -90,8 +107,8 @@ public:
 
 
 private:
-    FITSHistogram *histo;
-    int type;
+    FITSHistogram *histogram;
+    FITSScale type;
     int min, max;
     float *buffer;
     FITSTab *tab;
