@@ -78,6 +78,7 @@
 #include "tools/scriptbuilder.h"
 #include "tools/planetviewer.h"
 #include "tools/jmoontool.h"
+#include "tools/moonphasetool.h"
 #include "tools/flagmanager.h"
 #include "oal/execute.h"
 #include "projections/projector.h"
@@ -85,12 +86,12 @@
 #include <config-kstars.h>
 
 #ifdef HAVE_INDI_H
-#include "ui_devmanager.h"
-#include "indi/indimenu.h"
-#include "indi/indidriver.h"
+#include "ekos/ekosmanager.h"
 #include "indi/telescopewizardprocess.h"
 #include "indi/opsindi.h"
-#include "indi/imagesequence.h"
+#include "ekos/opsekos.h"
+#include "indi/drivermanager.h"
+#include "indi/guimanager.h"
 #endif
 
 #include "skycomponents/customcatalogcomponent.h"
@@ -103,7 +104,7 @@
 #ifdef HAVE_CFITSIO_H
 #include "fitsviewer/fitsviewer.h"
 #ifdef HAVE_INDI_H
-#include "ekos/ekos.h"
+//#include "ekos/ekos.h"
 #endif
 #endif
 
@@ -305,25 +306,25 @@ void KStars::slotJMoonTool() {
     jmt->show();
 }
 
+void KStars::slotMoonPhaseTool() {
+    if( ! mpt ) mpt = new MoonPhaseTool( this );
+    mpt->show();
+}
+
 void KStars::slotFlagManager() {
     if ( ! fm ) fm = new FlagManager(this);
     fm->show();
 }
 
-void KStars::slotImageSequence()
-{
-#ifdef HAVE_INDI_H
-    if (indiseq == NULL)
-        indiseq = new imagesequence(this);
-
-    if (indiseq->updateStatus())
-        indiseq->show();
-#endif
-}
-
 void KStars::slotTelescopeWizard()
 {
 #ifdef HAVE_INDI_H
+    if (KStandardDirs::findExe("indiserver").isEmpty())
+    {
+        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+        return;
+    }
+
     QPointer<telescopeWizardProcess> twiz = new telescopeWizardProcess(this);
     twiz->exec();
     delete twiz;
@@ -333,19 +334,25 @@ void KStars::slotTelescopeWizard()
 void KStars::slotINDIPanel() 
 {
 #ifdef HAVE_INDI_H
-    if (indimenu == NULL)
-        indimenu = new INDIMenu(this);
-
-    indimenu->updateStatus();
+    if (KStandardDirs::findExe("indiserver").isEmpty())
+    {
+        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+        return;
+    }
+    GUIManager::Instance()->updateStatus();
 #endif
 }
 
 void KStars::slotINDIDriver() 
 {
 #ifdef HAVE_INDI_H
-    if (indidriver == NULL)
-        indidriver = new INDIDriver(this);
-    indidriver->show();
+    if (KStandardDirs::findExe("indiserver").isEmpty())
+    {
+        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+        return;
+    }
+
+    DriverManager::Instance()->show();
 #endif
 }
 
@@ -353,8 +360,15 @@ void KStars::slotEkos()
 {
 #ifdef HAVE_CFITSIO_H
 #ifdef HAVE_INDI_H
+
+    if (KStandardDirs::findExe("indiserver").isEmpty())
+    {
+        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+        return;
+    }
+
     if (ekosmenu == NULL)
-        ekosmenu = new Ekos(this);
+        ekosmenu = new EkosManager();
 
     ekosmenu->show();
 #endif
@@ -429,6 +443,9 @@ void KStars::slotViewOps() {
     #ifdef HAVE_INDI_H
     opsindi = new OpsINDI (this);
     dialog->addPage(opsindi, i18n("INDI"), "kstars");
+
+    opsekos = new OpsEkos(this);
+    dialog->addPage(opsekos, i18n("Ekos"), "kstars");
     #endif
 
 #ifdef HAVE_XPLANET
@@ -539,8 +556,11 @@ void KStars::slotOpenFITS()
         return;
 
     FITSViewer * fv = new FITSViewer(this);
-    fv->addFITS(&fileURL);
-    fv->show();
+    // Error opening file
+    if (fv->addFITS(&fileURL) == -2)
+        delete (fv);
+    else
+       fv->show();
 #endif
 }
 
@@ -567,7 +587,7 @@ void KStars::slotExportImage() {
 }
 
 void KStars::slotRunScript() {
-    KUrl fileURL = KFileDialog::getOpenUrl( QDir::homePath(), "*.kstars|KStars Scripts (*.kstars)" );
+    KUrl fileURL = KFileDialog::getOpenUrl( QDir::homePath(), "*.kstars|" + i18nc("Filter by file type: KStars Scripts.", "KStars Scripts (*.kstars)") );
     QFile f;
     QString fname;
 
@@ -584,14 +604,14 @@ void KStars::slotRunScript() {
 
             if ( result == KMessageBox::Cancel ) return;
             if ( result == KMessageBox::No ) { //save file
-                KUrl saveURL = KFileDialog::getSaveUrl( QDir::homePath(), "*.kstars|KStars Scripts (*.kstars)" );
+                KUrl saveURL = KFileDialog::getSaveUrl( QDir::homePath(), "*.kstars|" + i18nc("Filter by file type: KStars Scripts.", "KStars Scripts (*.kstars)") );
                 KTemporaryFile tmpfile;
                 tmpfile.open();
 
                 while ( ! saveURL.isValid() ) {
                     message = i18n( "Save location is invalid. Try another location?" );
                     if ( KMessageBox::warningYesNo( 0, message, i18n( "Invalid Save Location" ), KGuiItem(i18n("Try Another")), KGuiItem(i18n("Do Not Try")) ) == KMessageBox::No ) return;
-                    saveURL = KFileDialog::getSaveUrl( QDir::homePath(), "*.kstars|KStars Scripts (*.kstars)" );
+                    saveURL = KFileDialog::getSaveUrl( QDir::homePath(), "*.kstars|" + i18nc("Filter by file type: KStars Scripts.", "KStars Scripts (*.kstars)") );
                 }
 
                 if ( saveURL.isLocalFile() ) {
@@ -1034,7 +1054,7 @@ void KStars::addColorMenuItem( const QString &name, const QString &actionName )
     colorActionMenu->addAction( kta );
 
     KConfigGroup cg = KGlobal::config()->group( "Colors" );
-    if ( actionName.mid( 3 ) == cg.readEntry( "ColorSchemeFile", "classic.colors" ).remove( ".colors" ) ) {
+    if ( actionName.mid( 3 ) == cg.readEntry( "ColorSchemeFile", "moonless-night.colors" ).remove( ".colors" ) ) {
         kta->setChecked( true );
     }
 }
@@ -1044,15 +1064,18 @@ void KStars::removeColorMenuItem( const QString &actionName ) {
     colorActionMenu->removeAction( actionCollection()->action( actionName ) );
 }
 
+/*
+
 void KStars::establishINDI()
 {
 #ifdef HAVE_INDI_H
     if (indimenu == NULL)
-        indimenu = new INDIMenu(this);
+        indimenu = GUIManager::Instance();
     if (indidriver == NULL)
-        indidriver = new INDIDriver(this);
+        indidriver = new DriverManager();
 #endif
 }
+*/
 
 void KStars::slotAboutToQuit()
 {
